@@ -49,9 +49,9 @@ bmRequest <- function(request, http_config, verbose = FALSE){
     result <- req_perform(request)
     
     result2 <- resp_body_string(result)
-    # if(is.na(result2)) {
-    #     result2 <- content(result, encoding = "Latin1")
-    # }
+    if(is.na(result2)) {
+         result2 <- resp_body_string(result, encoding = "Latin1")
+    }
     return(result2)
 }
 
@@ -134,7 +134,7 @@ listMarts <- function( mart = NULL, host="https://www.ensembl.org", path="/bioma
     
     ## create a table with the registry information
     marts <- do.call('rbind', lapply(registry_xml2, FUN = xml2::xml_attrs))
-    marts <- as.data.frame( marts[marts[,"visible"] == "1",] )
+    marts <- as.data.frame( marts[marts[,"visible"] == "1", , drop = FALSE] )
     ## rename some columns
     names(marts)[names(marts) == "name"] <- "biomart"
     names(marts)[names(marts) == "displayName"] <- "version"
